// text_experiments
// by Lee Spector, lspector@hampshire.edu
// Demonstrates simple sentence generation.
// Text output with print/println goes only to the console, not to graphic/applet display.
// This code demonstrates a simple way of sending text to the graphic/applet display as well.
// Lines that extend past the right hand side will be clipped, and wrapping past the bottom 
// overwrites from the top, without erasing.

// a few globals are used to specify font display parameters and to keep track of the line number
int margin = 20;
int font_size = 24;
int leading = 4;
int line_number = 0;

// the setup() method includes code to load and specify the font
void setup () {
  size(600, 400);
  background(255); // white
  noLoop();
  // Fonts must be placed within the data directory of your sketch
  //PFont fontA = loadFont("Ziggurat-HTF-Black-32.vlw");
  PFont fontA = loadFont("CourierNewPSMT-24.vlw");
  // Set the font and its size (in units of pixels)
  textFont(fontA, font_size);
}

// this textln method can be used in place of println to send text BOTH to the
// console and to the graphic/applet display
void textln(String text_to_print) {
  int max_lines = (height - (2 * margin)) / (font_size + leading);
  println(text_to_print);
  // Use fill() to change the value or color of the text
  fill(0);
  text(text_to_print, margin, margin + ((line_number + 1) *( font_size + leading)));
  line_number = (line_number + 1) % max_lines;
}

// From here down is code for generating very simple sentences.

// a utility to return a random element of an array of strings
String random_string (String[] string_array) {
  return string_array[int(random(string_array.length))];
}

// return a string containing a random article
String article () {
  String[] articles = { "a", "the", "my", "your" };
  return random_string(articles);
}
  
// return a string containing a random noun
String noun () {
  String[] nouns = { "man", "woman", "ball", "table", "fish", "dog", "airplane" };
  return random_string(nouns);
}

// return a string containing a random verb
String verb () {
  String[] verbs = { "hit", "took", "saw", "liked", "carried", "heard", "loved", "soothed", "hated" };
  return random_string(verbs);
}

// return a string containing a random sentence
String sentence () {
  return article() + " " + noun() + " " + verb() + " " + article() + " " + noun();
}


// top level draw function -- print some sentences
void draw () {
  textln(sentence());
  textln(sentence());
  textln(sentence());
}















