// turtle_sentence.pde
// Lee Spector (lspector@hampshire.edu), 2006
// A combination of class examples for turtle graphics and grammatical sentence generation.


////////////////////////////////////////////////////////////////////////////////
// Variables and procedures that implement simple turtle graphics commands

float xcor; 
float ycor; 
float angle; 
boolean penStateUp; 

void forward(float distance) { 
  float initial_xcor, initial_ycor; 
  initial_xcor = xcor; 
  initial_ycor = ycor; 
  xcor += distance*cos(radians(angle)); 
  ycor += distance*sin(radians(angle)); 
  if (penStateUp == false) { 
    line (initial_xcor, initial_ycor, xcor, ycor); 
  } 
} 

void back(float distance) { 
  float initial_xcor, initial_ycor; 
  initial_xcor = xcor; 
  initial_ycor = ycor; 
  xcor -= distance*cos(radians(angle)); 
  ycor -= distance*sin(radians(angle)); 
  if (penStateUp == false) { 
    line (initial_xcor, initial_ycor, xcor, ycor); 
  } 
} 

void right(float degree) { 
  angle += degree; 
  if (angle >= 360) { 
    angle -= 360; 
  } 
} 

void left(float degree) { 
  angle -= degree; 
  if (angle <= 0) { 
    angle += 360; 
  } 
} 

void penup() { 
  penStateUp = true; 
} 

void pendown() { 
  penStateUp = false; 
} 

void setxy(float x, float y) { 
  xcor = x; 
  ycor = y; 
} 

void setpc(float r, float g, float b) {
  stroke(r, g, b);
}

////////////////////////////////////////////////////////////////////////////////
// Top level procedures

void setup()  
{ 
  size(400, 400);            // set the window size
  background(255);           // set the background color
  setxy(width/2,height-50);  // move to near the bottom of the window
  angle = -90.0;             // the turtle starts facing up
  penStateUp = true;         // the pen is initially up
  setpc(0,0,0);              // pen color is initially black
  noLoop();                  // execute the draw procedure only once
} 

// grammar presented in class (originally from Winston's AI text?)

void s () {
  np();
  vp_pps();
}

void np () {
  det();
  adjs_noun();
}

void adjs_noun () {
  if (random(1) < 0.5) {
    adj();
    adjs_noun();
  } else {
    noun();
  }
}

void vp_pps () {
  if (random(1) < 0.5) {
    vp_pps();
    pp();
  } else {
    vp();
  }
}

void vp () {
  verb();
  np();
}

void pp () {
  prep();
  np();
}
  
void det () {
  setpc(0, 0, 0);
  forward(10);
}

void adj () {
  setpc(0, 255, 0);
  left(20);
  forward(10);
}

void noun () {
  setpc(255, 0, 0);
  forward(20);
}

void verb () {
  setpc(0, 0, 255);
  forward(20);
}

void prep () {
  setpc(128, 128, 128);
  right(40);
  forward(10);
}


void many_sentences () {
  for (int i = 0; i < 200; i = i + 1) {
    setxy(width/2,height-50);  // move to near the bottom of the window
    angle = -90.0;             // the turtle starts facing up
    setpc(0,0,0);              // pen color is initially black
    s();
  }
}


void draw () {
  pendown();
  
  //s();
  
  many_sentences();
}

